<?php
/**
 *----------------------------------------------------------------------------
 * iCagenda     Events Management Extension for Joomla!
 *----------------------------------------------------------------------------
 * @version     3.8.0 2021-12-03
 *
 * @package     iCagenda.Admin
 * @subpackage  src.Extension
 * @link        https://www.icagenda.com
 *
 * @author      Cyril Rezé
 * @copyright   (c) 2012-2022 Cyril Rezé / iCagenda. All rights reserved.
 * @license     GNU General Public License version 3 or later; see LICENSE.txt
 *
 * @since       3.8
 *----------------------------------------------------------------------------
*/

namespace WebiC\Component\iCagenda\Administrator\Extension;

\defined('JPATH_PLATFORM') or die;

use Joomla\CMS\Application\SiteApplication;
use Joomla\CMS\Component\Router\RouterServiceInterface;
use Joomla\CMS\Component\Router\RouterServiceTrait;
use Joomla\CMS\Extension\BootableExtensionInterface;
use Joomla\CMS\Extension\MVCComponent;
use Joomla\CMS\Factory;
use Joomla\CMS\Form\Form;
use Joomla\CMS\Form\FormHelper;
use Joomla\CMS\Helper\ContentHelper as LibraryContentHelper;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\HTML\HTMLRegistryAwareTrait;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\PluginHelper;
use Psr\Container\ContainerInterface;
use WebiC\Component\iCagenda\Administrator\Service\HTML\Themes;

/**
 * Component class for com_icagenda
 */
class iCagendaComponent extends MVCComponent implements
	RouterServiceInterface,
	BootableExtensionInterface
{
	use RouterServiceTrait;
	use HTMLRegistryAwareTrait;

	/**
	 * The trashed condition
	 */
	const CONDITION_NAMES = [
		self::CONDITION_PUBLISHED   => 'JPUBLISHED',
		self::CONDITION_UNPUBLISHED => 'JUNPUBLISHED',
		self::CONDITION_ARCHIVED    => 'JARCHIVED',
		self::CONDITION_TRASHED     => 'JTRASHED',
	];

	/**
	 * The archived condition
	 */
	const CONDITION_ARCHIVED = 2;

	/**
	 * The published condition
	 */
	const CONDITION_PUBLISHED = 1;

	/**
	 * The unpublished condition
	 */
	const CONDITION_UNPUBLISHED = 0;

	/**
	 * The trashed condition
	 */
	const CONDITION_TRASHED = -2;

	/**
	 * Booting the extension. This is the function to set up the environment of the extension like
	 * registering new class loaders, etc.
	 *
	 * If required, some initial set up can be done from services of the container, eg.
	 * registering HTML services.
	 *
	 * @param   ContainerInterface  $container  The container
	 *
	 * @return  void
	 */
	public function boot(ContainerInterface $container)
	{
		// Get Application
		$app = Factory::getApplication();

		// Check Errors: iC Library & iCagenda Utilities
		$UTILITIES_DIR = is_dir(JPATH_ADMINISTRATOR . '/components/com_icagenda/utilities');

		if ( ( ! $UTILITIES_DIR)
			|| ( ! class_exists('iCLibrary')) )
		{
			$alert_message = Text::_('ICAGENDA_CAN_NOT_LOAD') . '<br />';
			$alert_message.= '<ul>';
			if ( ! class_exists('iCLibrary')) $alert_message.= '<li>' . Text::_('IC_LIBRARY_NOT_LOADED') . '</li>';
			if ( ! $UTILITIES_DIR) $alert_message.= '<li>' . Text::_('ICAGENDA_A_FOLDER_IS_MISSING') . '</li>';
			$alert_message.= '</ul>';
			if ( ! $UTILITIES_DIR) $alert_message.= Text::_('ICAGENDA_IS_NOT_CORRECTLY_INSTALLED') . ' ';
			if ( ! $UTILITIES_DIR) $alert_message.= Text::_('ICAGENDA_INSTALL_AGAIN') . '<br />';
			if ( ! $UTILITIES_DIR) $alert_message.= Text::_('IC_ALTERNATIVELY') . ':<br /><ul>';
			if ($UTILITIES_DIR) $alert_message.= Text::_('IC_PLEASE') . ', ';
			if ( ! class_exists('iCLibrary'))
			{
				if ( ! $UTILITIES_DIR) $alert_message.= '<li>';
				$alert_message.= Text::_('IC_LIBRARY_CHECK_PLUGIN_AND_LIBRARY');
				if ( ! $UTILITIES_DIR) $alert_message.= '</li>';
			}
			if ( ! $UTILITIES_DIR)
			{
				$alert_message.= '<li>' . Text::Sprintf('ICAGENDA_UTILITIES_FIX_MANUAL'
								, '<strong>admin/utilities</strong>'
								, '<strong>administrator/components/com_icagenda/</strong>');
				$alert_message.= '</li></ul>';
			}

			// Get the message queue
			$messages = $app->getMessageQueue();

			$display_alert_message = false;

			// If we have messages
			if (is_array($messages) && count($messages))
			{
				// Check each message for the one we want
				foreach ($messages as $key => $value)
				{
					if ($value['message'] == $alert_message)
					{
						$display_alert_message = true;
					}
				}
			}

			if ( ! $display_alert_message)
			{
				$app->enqueueMessage($alert_message, 'error');

				return;
			}
		}
		else
		{
			// Loads Utilities
			\JLoader::registerNamespace('iCutilities', JPATH_ADMINISTRATOR . '/components/com_icagenda/src/Utilities');

			// Common fields
			FormHelper::addFieldPath(JPATH_ADMINISTRATOR . '/components/com_icagenda/utilities/form/field');

			PluginHelper::importPlugin('icagenda');

			if ( ! defined('IC_LIBRARY')) // To be checked.
			{
				define('IC_LIBRARY', true);
			}
		}

		$this->getRegistry()->register('themes', new Themes);
	}
}
